==> tuia-treasure-center-api-0.0.18.zr2-20180905.105651-2-sources.jar: cn/tuia/tuia/treasure/center/api/dto/statistics/newsarticledata/agentaspect/NewsArticleDailyDataAgentAspectDto.java <==
package cn.tuia.tuia.treasure.center.api.dto.statistics.newsarticledata.agentaspect;

import cn.tuia.tuia.treasure.center.api.dto.BaseQueryDto;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by zhou_wb on 2018/5/25.
 */
public class NewsArticleDailyDataAgentAspectDto implements Serializable {

    private static final long serialVersionUID = -8837658152088268759L;
    /**
     * id
     */
    private Long id;

    /**
     * 代理商id
     */
    private Long agentId;


    /**
     * 文章曝光pv(代理商维度)
     */
    private Long articleExposurePv;

    /**
     * 文章点击pv(代理商维度)
     */
    private Long articleClickPv;

    /**
     * 文章点击uv(代理商维度)
     */
    private Long articleClickUv;

    /**
     * 当天时间
     */
    private Date curDate;

    /**
     * 广告点击pv
     */
    private Long advertClickPv;

    /**
     * 广告曝光
     */
    private Long advertExposurePv;

    /**
     * 媒体文章曝光量
     */
    private Long mediaArticleExposure;

    /**
     * 媒体文章点击量
     */
    private Long mediaArticleClick;

    /**
     * 文章点击率
     */
    private Integer articleClickRate;


    /**
     * 媒体文章点击率
     * @return
     */
    private Integer articleMediaClickRate;

    /**
     * 分润比例
     */
    private Integer proportion;

    /**
     * 分成比例
     */
    private Integer finalProportion;

    /**
     * 千次曝光计费
     */
    private Long mexposurePrice;

    /**
     *代理商维度总收益
     */
    private Long totalIncome;

    /**
     * 应得广告收益
     */
    private Long shouldIncome;

    /**
     * 实际收益
     */
    private Long finalIncome;

    /**
     * ecpm
     */
    private Long ecpm;


    /**
     * 媒体cpm
     */
    private Long mediaCpm;

    /**
     * 当天文章数量
     */
    private Long articleCount;

    /**
     * 子账号数量
     */
    private Long subAccountCount;

    /**
     * 广告点击率
     * @return
     */
    private Integer advertClickRate;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }

    public Long getArticleExposurePv() {
        return articleExposurePv;
    }

    public void setArticleExposurePv(Long articleExposurePv) {
        this.articleExposurePv = articleExposurePv;
    }

    public Long getArticleClickPv() {
        return articleClickPv;
    }

    public void setArticleClickPv(Long articleClickPv) {
        this.articleClickPv = articleClickPv;
    }

    public Long getArticleClickUv() {
        return articleClickUv;
    }

    public void setArticleClickUv(Long articleClickUv) {
        this.articleClickUv = articleClickUv;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Long getAdvertClickPv() {
        return advertClickPv;
    }

    public void setAdvertClickPv(Long advertClickPv) {
        this.advertClickPv = advertClickPv;
    }

    public Long getAdvertExposurePv() {
        return advertExposurePv;
    }

    public void setAdvertExposurePv(Long advertExposurePv) {
        this.advertExposurePv = advertExposurePv;
    }

    public Long getMediaArticleExposure() {
        return mediaArticleExposure;
    }

    public void setMediaArticleExposure(Long mediaArticleExposure) {
        this.mediaArticleExposure = mediaArticleExposure;
    }

    public Long getMediaArticleClick() {
        return mediaArticleClick;
    }

    public void setMediaArticleClick(Long mediaArticleClick) {
        this.mediaArticleClick = mediaArticleClick;
    }

    public Integer getArticleClickRate() {
        return articleClickRate;
    }

    public void setArticleClickRate(Integer articleClickRate) {
        this.articleClickRate = articleClickRate;
    }

    public Integer getArticleMediaClickRate() {
        return articleMediaClickRate;
    }

    public void setArticleMediaClickRate(Integer articleMediaClickRate) {
        this.articleMediaClickRate = articleMediaClickRate;
    }

    public Integer getProportion() {
        return proportion;
    }

    public void setProportion(Integer proportion) {
        this.proportion = proportion;
    }

    public Integer getFinalProportion() {
        return finalProportion;
    }

    public void setFinalProportion(Integer finalProportion) {
        this.finalProportion = finalProportion;
    }

    public Long getMexposurePrice() {
        return mexposurePrice;
    }

    public void setMexposurePrice(Long mexposurePrice) {
        this.mexposurePrice = mexposurePrice;
    }

    public Long getShouldIncome() {
        return shouldIncome;
    }

    public void setShouldIncome(Long shouldIncome) {
        this.shouldIncome = shouldIncome;
    }

    public Long getFinalIncome() {
        return finalIncome;
    }

    public void setFinalIncome(Long finalIncome) {
        this.finalIncome = finalIncome;
    }

    public Long getEcpm() {
        return ecpm;
    }

    public void setEcpm(Long ecpm) {
        this.ecpm = ecpm;
    }

    public Long getMediaCpm() {
        return mediaCpm;
    }

    public void setMediaCpm(Long mediaCpm) {
        this.mediaCpm = mediaCpm;
    }

    public Long getTotalIncome() {
        return totalIncome;
    }

    public void setTotalIncome(Long totalIncome) {
        this.totalIncome = totalIncome;
    }

    public Long getArticleCount() {
        return articleCount;
    }

    public void setArticleCount(Long articleCount) {
        this.articleCount = articleCount;
    }

    public Long getSubAccountCount() {
        return subAccountCount;
    }

    public void setSubAccountCount(Long subAccountCount) {
        this.subAccountCount = subAccountCount;
    }

    public Integer getAdvertClickRate() {
        return advertClickRate;
    }

    public void setAdvertClickRate(Integer advertClickRate) {
        this.advertClickRate = advertClickRate;
    }
}

==> tuia-treasure-center-api-0.0.20-zr3-20180926.122416-2-sources.jar: cn/tuia/tuia/treasure/center/api/dto/statistics/newsarticledata/agentaspect/NewsArticleDailyDataAgentAspectDto.java <==
package cn.tuia.tuia.treasure.center.api.dto.statistics.newsarticledata.agentaspect;

import cn.tuia.tuia.treasure.center.api.dto.BaseQueryDto;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by zhou_wb on 2018/5/25.
 */
public class NewsArticleDailyDataAgentAspectDto implements Serializable {

    private static final long serialVersionUID = -8837658152088268759L;
    /**
     * id
     */
    private Long id;

    /**
     * 代理商id
     */
    private Long agentId;


    /**
     * 文章曝光pv(代理商维度)
     */
    private Long articleExposurePv;

    /**
     * 文章点击pv(代理商维度)
     */
    private Long articleClickPv;

    /**
     * 文章点击uv(代理商维度)
     */
    private Long articleClickUv;

    /**
     * 当天时间
     */
    private Date curDate;

    /**
     * 广告点击pv
     */
    private Long advertClickPv;

    /**
     * 广告曝光
     */
    private Long advertExposurePv;

    /**
     * 媒体文章曝光量
     */
    private Long mediaArticleExposure;

    /**
     * 媒体文章点击量
     */
    private Long mediaArticleClick;

    /**
     * 文章点击率
     */
    private Integer articleClickRate;


    /**
     * 媒体文章点击率
     * @return
     */
    private Integer articleMediaClickRate;

    /**
     * 分润比例
     */
    private Integer proportion;

    /**
     * 分成比例
     */
    private Integer finalProportion;

    /**
     * 千次曝光计费
     */
    private Long mexposurePrice;

    /**
     *代理商维度总收益
     */
    private Long totalIncome;

    /**
     * 应得广告收益
     */
    private Long shouldIncome;

    /**
     * 实际收益
     */
    private Long finalIncome;

    /**
     * ecpm
     */
    private Long ecpm;


    /**
     * 媒体cpm
     */
    private Long mediaCpm;

    /**
     * 对外cpm
     */
    private Long outterCpm;

    /**
     * 当天文章数量
     */
    private Long articleCount;

    /**
     * 子账号数量
     */
    private Long subAccountCount;

    /**
     * 广告点击率
     * @return
     */
    private Integer advertClickRate;

    public Long getOutterCpm() {
        return outterCpm;
    }

    public void setOutterCpm(Long outterCpm) {
        this.outterCpm = outterCpm;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }

    public Long getArticleExposurePv() {
        return articleExposurePv;
    }

    public void setArticleExposurePv(Long articleExposurePv) {
        this.articleExposurePv = articleExposurePv;
    }

    public Long getArticleClickPv() {
        return articleClickPv;
    }

    public void setArticleClickPv(Long articleClickPv) {
        this.articleClickPv = articleClickPv;
    }

    public Long getArticleClickUv() {
        return articleClickUv;
    }

    public void setArticleClickUv(Long articleClickUv) {
        this.articleClickUv = articleClickUv;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Long getAdvertClickPv() {
        return advertClickPv;
    }

    public void setAdvertClickPv(Long advertClickPv) {
        this.advertClickPv = advertClickPv;
    }

    public Long getAdvertExposurePv() {
        return advertExposurePv;
    }

    public void setAdvertExposurePv(Long advertExposurePv) {
        this.advertExposurePv = advertExposurePv;
    }

    public Long getMediaArticleExposure() {
        return mediaArticleExposure;
    }

    public void setMediaArticleExposure(Long mediaArticleExposure) {
        this.mediaArticleExposure = mediaArticleExposure;
    }

    public Long getMediaArticleClick() {
        return mediaArticleClick;
    }

    public void setMediaArticleClick(Long mediaArticleClick) {
        this.mediaArticleClick = mediaArticleClick;
    }

    public Integer getArticleClickRate() {
        return articleClickRate;
    }

    public void setArticleClickRate(Integer articleClickRate) {
        this.articleClickRate = articleClickRate;
    }

    public Integer getArticleMediaClickRate() {
        return articleMediaClickRate;
    }

    public void setArticleMediaClickRate(Integer articleMediaClickRate) {
        this.articleMediaClickRate = articleMediaClickRate;
    }

    public Integer getProportion() {
        return proportion;
    }

    public void setProportion(Integer proportion) {
        this.proportion = proportion;
    }

    public Integer getFinalProportion() {
        return finalProportion;
    }

    public void setFinalProportion(Integer finalProportion) {
        this.finalProportion = finalProportion;
    }

    public Long getMexposurePrice() {
        return mexposurePrice;
    }

    public void setMexposurePrice(Long mexposurePrice) {
        this.mexposurePrice = mexposurePrice;
    }

    public Long getShouldIncome() {
        return shouldIncome;
    }

    public void setShouldIncome(Long shouldIncome) {
        this.shouldIncome = shouldIncome;
    }

    public Long getFinalIncome() {
        return finalIncome;
    }

    public void setFinalIncome(Long finalIncome) {
        this.finalIncome = finalIncome;
    }

    public Long getEcpm() {
        return ecpm;
    }

    public void setEcpm(Long ecpm) {
        this.ecpm = ecpm;
    }

    public Long getMediaCpm() {
        return mediaCpm;
    }

    public void setMediaCpm(Long mediaCpm) {
        this.mediaCpm = mediaCpm;
    }

    public Long getTotalIncome() {
        return totalIncome;
    }

    public void setTotalIncome(Long totalIncome) {
        this.totalIncome = totalIncome;
    }

    public Long getArticleCount() {
        return articleCount;
    }

    public void setArticleCount(Long articleCount) {
        this.articleCount = articleCount;
    }

    public Long getSubAccountCount() {
        return subAccountCount;
    }

    public void setSubAccountCount(Long subAccountCount) {
        this.subAccountCount = subAccountCount;
    }

    public Integer getAdvertClickRate() {
        return advertClickRate;
    }

    public void setAdvertClickRate(Integer advertClickRate) {
        this.advertClickRate = advertClickRate;
    }
}
